@@ -33,7 +33,7 @@ sed -i -- 's/make-options -j8/make-options -j4 VERBOSE=1/g' kdesrc-conf-android/
 
 if [ -e $qt_android_libs ]
 then
-    sed -E -i "s|-DCMAKE_PREFIX_PATH=.*?\\ |-DCMAKE_PREFIX_PATH=$QT_ANDROID- -DCMAKE_ANDROID_NDK=$CMAKE_ANDROID_NDK -DECM_ADDITIONAL_FIND_ROOT_PATH=$QT_ANDROID\;$CURDIR/kf5/kde/install -DANDROID_STL=gnustl_static |g" kdesrc-conf-android/kdesrc-buildrc
+    sed -E -i "s|-DCMAKE_PREFIX_PATH=.*?\\ |-DCMAKE_PREFIX_PATH=$QT_ANDROID- -DCMAKE_ANDROID_NDK=$CMAKE_ANDROID_NDK -DECM_ADDITIONAL_FIND_ROOT_PATH=$QT_ANDROID\;$CURDIR/kf5/kde/install -DANDROID_STL=gnustl_static -DCMAKE_TOOLCHAIN_FILE=/usr/share/ECM/toolchain/Android.cmake |g" kdesrc-conf-android/kdesrc-buildrc
 else
     echo "Qt Android libraries path doesn't exist. Exiting."
     exit
@@ -43,13 +43,13 @@ sed -E -i "s|use-modules.+|use-modules kconfig ki18n kplotting|g" kdesrc-conf-an
 rm -rf ${kf5_android_path}/kde/build/${android_architecture}/* # clean build folders
 # Build ki18n first to get the sources, it needs to be patched
 ./kdesrc-build libintl-lite ki18n
+sed -i -- 's/check_cxx_source_compiles/#check_cxx_source_compiles/g' kde/src/frameworks/ki18n/cmake/FindLibIntl.cmake
 sed -i -- 's/target_link_libraries(ktranscript PRIVATE Qt5::Script Qt5::Core)/target_link_libraries(ktranscript PRIVATE Qt5::Script Qt5::Core -l:libc.a -Wl,--exclude-libs=ALL)/g' $CURDIR/kf5/kde/src/frameworks/ki18n/src/CMakeLists.txt
 ./kdesrc-build libintl-lite extra-cmake-modules frameworks-android
 
 # Fix some config files
-sed -i '/find_package(PythonInterp/ s/^/#/' kde/install/lib/cmake/KF5I18n/KF5I18NMacros.cmake
+sed -i '/find_package(PythonInterp/ s/^/#/' kde/install/lib/cmake/KF5I18n/KF5I18nMacros.cmake
 sed -i '/find_dependency(Qt5Xml/ s/^/#/' kde/install/lib/cmake/KF5Config/KF5ConfigConfig.cmake
-#sed -i '/cxx_decltype/ s/^/#/' ${QT_ANDROID}/lib/cmake/Qt5Core/Qt5CoreConfigExtras.cmake
 
 cp /usr/lib/x86_64-linux-gnu/libexec/kf5/kconfig_compiler_kf5 $CURDIR/kf5/kde/install/lib/libexec/kf5/kconfig_compiler_kf5
 
