@@ -152,14 +152,27 @@ class CatalogDB
      **/
     bool AddEntry(const CatalogEntryData &catalog_entry, int catid);
 
+    /**
+     * @brief Check an entry in the database
+     *
+     * @note This public method opens and closes the database.
+     *
+     * @param entry_long_name Long name of the entry
+     * @param catid Category ID in the database
+     * @return True if successful otherwise false
+     **/
+    bool CheckCustomEntry(const QString &entry_long_name, int catid);
+
     /**
      * @brief Remove an entry from the database
      *
      * @note This public method opens and closes the database.
      *
      * @param entry_long_name Long name of the entry
+     * @param catid Category ID in the database
+     * @return True if successful otherwise false
      **/
-    bool RemoveCustomEntry(const QString &entry_long_name);
+    bool RemoveCustomEntry(const QString &entry_long_name, int catid);
 
     /**
      * @brief Returns database ID of the required catalog.
