@@ -11,11 +11,19 @@
 #pragma once
 
 #include <KLocalizedString>
-
 #include <QString>
 
 namespace KSNotification
 {
+
+typedef enum
+{
+    EVENT_DBG,
+    EVENT_INFO,
+    EVENT_WARN,
+    EVENT_ALERT
+} EventType;
+
 void error(const QString &message, const QString &title = i18n("Error"));
 void sorry(const QString &message, const QString &title = i18n("Sorry"));
 void info(const QString &message, const QString &title = i18n("Info"));
@@ -25,4 +33,6 @@ void info(const QString &message, const QString &title = i18n("Info"));
  * @param title message title
  */
 void transient(const QString &message, const QString &title);
+
+void event(const QLatin1String &name, const QString &message, EventType type = EVENT_INFO);
 }
