@@ -12,15 +12,20 @@
 
 #include <QMap>
 #include <QString>
+#include <QJsonObject>
 
 class ProfileInfo
 {
   public:
     ProfileInfo(int id, const QString &name);
-    ~ProfileInfo() {}
+    ~ProfileInfo() = default;
 
     // Is connection local or remote
     bool isLocal() { return host.isEmpty(); }
+    QJsonObject toJson() const
+    {
+        return {{"name", name}, {"isLocal", host.isEmpty()}};
+    }
 
     QString mount();
     QString ccd();
@@ -34,6 +39,7 @@ class ProfileInfo
     QString aux2();
     QString aux3();
     QString aux4();
+    QString remoteDrivers();
 
     QString name;
     QString host;
@@ -44,6 +50,7 @@ class ProfileInfo
     int guiderport { 0 };
     int primaryscope { 0 };
     int guidescope { 0 };
+    QString remotedrivers;
     QString guiderhost;
     int id { 0 };
     int port { -1 };
