@@ -250,7 +250,7 @@ void FindDialog::filterList()
 {
     QString SearchText = processSearchText();
     sortModel->setFilterFixedString(SearchText);
-    ui->InternetSearchButton->setText(i18n("or search the internet for %1", SearchText));
+    ui->InternetSearchButton->setText(i18n("or search the Internet for %1", SearchText));
     filterByType();
     initSelection();
 
@@ -355,9 +355,9 @@ void FindDialog::finishProcessing(SkyObject *selObj, bool resolve)
 {
     if (!selObj && resolve)
     {
-        CatalogEntryData cedata;
-        cedata             = NameResolver::resolveName(processSearchText());
+        CatalogEntryData cedata = NameResolver::resolveName(processSearchText());
         DeepSkyObject *dso = nullptr;
+
         if (!std::isnan(cedata.ra) && !std::isnan(cedata.dec))
         {
             dso = KStarsData::Instance()->skyComposite()->internetResolvedComponent()->addObject(cedata);
