@@ -8,13 +8,14 @@
     version 2 of the License, or (at your option) any later version.
 */
 
-#include <KConfigDialog>
-
 #include "opsastrometry.h"
-#include "kstars.h"
+
 #include "align.h"
+#include "kstars.h"
 #include "Options.h"
 
+#include <KConfigDialog>
+
 namespace Ekos
 {
 OpsAstrometry::OpsAstrometry(Align *parent) : QWidget(KStars::Instance())
@@ -50,10 +51,6 @@ OpsAstrometry::OpsAstrometry(Align *parent) : QWidget(KStars::Instance())
     updatePosition->setAttribute(Qt::WA_LayoutUsesWidgetRect);
 }
 
-OpsAstrometry::~OpsAstrometry()
-{
-}
-
 void OpsAstrometry::showEvent(QShowEvent *)
 {
     dms ra, de;
@@ -70,7 +67,7 @@ void OpsAstrometry::slotUpdateScale()
     double fov_w, fov_h, fov_pixscale;
 
     // Values in arcmins. Scale in arcsec per pixel
-    alignModule->getFOVScale(fov_w, fov_h, fov_pixscale);
+    alignModule->getCalculatedFOVScale(fov_w, fov_h, fov_pixscale);
 
     if (fov_w == 0 || fov_h == 0)
     {
