@@ -45,7 +45,7 @@ bool InternalGuider::guide()
 
     if (state >= GUIDE_GUIDING)
     {
-        if (imageGuideEnabled)
+        if (m_ImageGuideEnabled)
             return processImageGuiding();
         else
             return processGuiding();
@@ -56,7 +56,7 @@ bool InternalGuider::guide()
     pmath->start();
 
     m_starLostCounter = 0;
-    m_highPulseCounter= 0;
+    m_highRMSCounter= 0;
 
     // TODO re-enable rapid check later on
 #if 0
@@ -78,7 +78,7 @@ bool InternalGuider::guide()
 
 #endif
 
-    isFirstFrame = true;
+    m_isFirstFrame = true;
 
     state = GUIDE_GUIDING;
     emit newStatus(state);
@@ -109,7 +109,7 @@ bool InternalGuider::abort()
     }
 
     m_starLostCounter=0;
-    m_highPulseCounter=0;
+    m_highRMSCounter=0;
     accumulator.first = accumulator.second = 0;
 
     pmath->suspend(false);
@@ -142,11 +142,11 @@ bool InternalGuider::resume()
 
 bool InternalGuider::ditherXY(int x, int y)
 {
-    ditherRetries=0;
+    m_DitherRetries=0;
     double cur_x, cur_y, ret_angle;
     pmath->getReticleParameters(&cur_x, &cur_y, &ret_angle);
-    ditherTargetPosition = Vector(x, y, 0);
-    pmath->setReticleParameters(ditherTargetPosition.x, ditherTargetPosition.y, ret_angle);
+    m_DitherTargetPosition = Vector(x, y, 0);
+    pmath->setReticleParameters(m_DitherTargetPosition.x, m_DitherTargetPosition.y, ret_angle);
 
     state = GUIDE_DITHERING;
     emit newStatus(state);
@@ -165,7 +165,7 @@ bool InternalGuider::dither(double pixels)
 
     if (state != GUIDE_DITHERING)
     {
-        ditherRetries = 0;
+        m_DitherRetries = 0;
 
         auto seed = std::chrono::system_clock::now().time_since_epoch().count();
         std::default_random_engine generator(seed);
@@ -185,11 +185,11 @@ bool InternalGuider::dither(double pixels)
             diff_y *= -1;
         accumulator.second += diff_y;
 
-        ditherTargetPosition = Vector(cur_x, cur_y, 0) + Vector(diff_x, diff_y, 0);
+        m_DitherTargetPosition = Vector(cur_x, cur_y, 0) + Vector(diff_x, diff_y, 0);
 
-        qCDebug(KSTARS_EKOS_GUIDE) << "Dithering process started.. Reticle Target Pos X " << ditherTargetPosition.x << " Y " << ditherTargetPosition.y;
+        qCDebug(KSTARS_EKOS_GUIDE) << "Dithering process started.. Reticle Target Pos X " << m_DitherTargetPosition.x << " Y " << m_DitherTargetPosition.y;
 
-        pmath->setReticleParameters(ditherTargetPosition.x, ditherTargetPosition.y, ret_angle);
+        pmath->setReticleParameters(m_DitherTargetPosition.x, m_DitherTargetPosition.y, ret_angle);
 
         state = GUIDE_DITHERING;
         emit newStatus(state);
@@ -199,7 +199,7 @@ bool InternalGuider::dither(double pixels)
         return true;
     }
 
-    Vector star_pos = Vector(cur_x, cur_y, 0) - Vector(ditherTargetPosition.x, ditherTargetPosition.y, 0);
+    Vector star_pos = Vector(cur_x, cur_y, 0) - Vector(m_DitherTargetPosition.x, m_DitherTargetPosition.y, 0);
     star_pos.y      = -star_pos.y;
     star_pos        = star_pos * ROT_Z;
 
@@ -220,7 +220,7 @@ bool InternalGuider::dither(double pixels)
     }
     else
     {
-        if (++ditherRetries > Options::ditherMaxIterations())
+        if (++m_DitherRetries > Options::ditherMaxIterations())
         {
             if (Options::ditherFailAbortsAutoGuide())
             {
@@ -269,7 +269,7 @@ bool InternalGuider::calibrate()
         ccdInfo = false;
     }
 
-    if (mountAperture == 0 || mountFocalLength == 0)
+    if (mountAperture == 0.0 || mountFocalLength == 0.0)
     {
         scopeInfo = false;
         if (ccdInfo == false)
@@ -380,31 +380,30 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
     {
     case CAL_START:
         //----- automatic mode -----
-        auto_drift_time = Options::autoModeIterations();
-        turn_back_time = auto_drift_time * 7;
+        m_CalibrationParams.auto_drift_time = Options::autoModeIterations();
+        m_CalibrationParams.turn_back_time = m_CalibrationParams.auto_drift_time * 7;
 
-        ra_iterations = 0;
-        dec_iterations = 0;
-        m_BacklastCounter = 0;
-        m_RATotalPulse = m_DETotalPulse = 0;
+        m_CalibrationParams.ra_iterations = 0;
+        m_CalibrationParams.dec_iterations = 0;
+        m_CalibrationParams.ra_total_pulse = m_CalibrationParams.de_total_pulse = 0;
 
         emit newLog(i18n("RA drifting forward..."));
 
-        pmath->getReticleParameters(&start_x1, &start_y1, nullptr);
+        pmath->getReticleParameters(&m_CalibrationCoords.start_x1, &m_CalibrationCoords.start_y1, nullptr);
 
-        m_LastPulse = Options::calibrationPulseDuration();
+        m_CalibrationParams.last_pulse = Options::calibrationPulseDuration();
 
-        qCDebug(KSTARS_EKOS_GUIDE) << "Auto Iteration #" << auto_drift_time << "Default pulse:" << m_LastPulse;
-        qCDebug(KSTARS_EKOS_GUIDE) << "Start X1 " << start_x1 << " Start Y1 " << start_y1;
+        qCDebug(KSTARS_EKOS_GUIDE) << "Auto Iteration #" << m_CalibrationParams.auto_drift_time << "Default pulse:" << m_CalibrationParams.last_pulse;
+        qCDebug(KSTARS_EKOS_GUIDE) << "Start X1 " << m_CalibrationCoords.start_x1 << " Start Y1 " << m_CalibrationCoords.start_y1;
 
         axis_calibration_complete = false;
 
-        last_x = start_x1;
-        last_y = start_x2;
+        m_CalibrationCoords.last_x = m_CalibrationCoords.start_x1;
+        m_CalibrationCoords.last_y = m_CalibrationCoords.start_x2;
 
-        emit newPulse(RA_INC_DIR, m_LastPulse);
+        emit newPulse(RA_INC_DIR, m_CalibrationParams.last_pulse);
 
-        ra_iterations++;
+        m_CalibrationParams.ra_iterations++;
 
         calibrationStage = CAL_RA_INC;
 
@@ -416,33 +415,35 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
         double cur_x, cur_y;
         pmath->getStarScreenPosition(&cur_x, &cur_y);
 
-        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration #" << ra_iterations << ": STAR " << cur_x << "," << cur_y;
-        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration " << ra_iterations << " Direction: RA_INC_DIR" << " Duration: " << m_LastPulse << " ms.";
+        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration #" << m_CalibrationParams.ra_iterations << ": STAR " << cur_x << "," << cur_y;
+        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration " << m_CalibrationParams.ra_iterations << " Direction: RA_INC_DIR" << " Duration: " << m_CalibrationParams.last_pulse << " ms.";
 
         // Must pass at least 1.5 pixels to move on to the next stage
-        if (ra_iterations >= auto_drift_time && (fabs(cur_x-start_x1) > 1.5 || fabs(cur_y-start_y1) > 1.5))
+        if (m_CalibrationParams.ra_iterations >= m_CalibrationParams.auto_drift_time && (fabs(cur_x-m_CalibrationCoords.start_x1) > 1.5 || fabs(cur_y-m_CalibrationCoords.start_y1) > 1.5))
         {
-            m_RATotalPulse += m_LastPulse;
+            m_CalibrationParams.ra_total_pulse += m_CalibrationParams.last_pulse;
 
             calibrationStage = CAL_RA_DEC;
 
-            end_x1 = cur_x;
-            end_y1 = cur_y;
+            m_CalibrationCoords.end_x1 = cur_x;
+            m_CalibrationCoords.end_y1 = cur_y;
 
-            last_x = cur_x;
-            last_y = cur_y;
+            m_CalibrationCoords.last_x = cur_x;
+            m_CalibrationCoords.last_y = cur_y;
 
-            qCDebug(KSTARS_EKOS_GUIDE) << "End X1 " << end_x1 << " End Y1 " << end_y1;
+            qCDebug(KSTARS_EKOS_GUIDE) << "End X1 " << m_CalibrationCoords.end_x1 << " End Y1 " << m_CalibrationCoords.end_y1;
 
-            phi   = pmath->calculatePhi(start_x1, start_y1, end_x1, end_y1);
-            ROT_Z = RotateZ(-M_PI * phi / 180.0); // derotates...
+            m_CalibrationParams.phi   = pmath->calculatePhi(m_CalibrationCoords.start_x1, m_CalibrationCoords.start_y1, m_CalibrationCoords.end_x1, m_CalibrationCoords.end_y1);
+            ROT_Z = RotateZ(-M_PI * m_CalibrationParams.phi / 180.0); // derotates...
 
-            emit newPulse(RA_DEC_DIR, m_LastPulse);
-            ra_iterations++;
+            m_CalibrationCoords.ra_distance = 0;
+
+            emit newPulse(RA_DEC_DIR, m_CalibrationParams.last_pulse);
+            m_CalibrationParams.ra_iterations++;
 
             emit newLog(i18n("RA drifting reverse..."));
         }
-        else if (ra_iterations > turn_back_time)
+        else if (m_CalibrationParams.ra_iterations > m_CalibrationParams.turn_back_time)
         {
             emit newLog(i18n("Calibration rejected. Star drift is too short. Check for mount, cable, or backlash problems."));
 
@@ -457,23 +458,23 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
         else
         {
             // Aggressive pulse in case we're going slow
-            if (fabs(cur_x-last_x) < 0.5 && fabs(cur_y-last_y) < 0.5)
+            if (fabs(cur_x-m_CalibrationCoords.last_x) < 0.5 && fabs(cur_y-m_CalibrationCoords.last_y) < 0.5)
             {
                 // 200%
-                m_LastPulse = Options::calibrationPulseDuration() *2;
+                m_CalibrationParams.last_pulse = Options::calibrationPulseDuration() *2;
             }
             else
             {
-                m_RATotalPulse += m_LastPulse;
-                m_LastPulse = Options::calibrationPulseDuration();
+                m_CalibrationParams.ra_total_pulse += m_CalibrationParams.last_pulse;
+                m_CalibrationParams.last_pulse = Options::calibrationPulseDuration();
             }
 
-            last_x = cur_x;
-            last_y = cur_y;
+            m_CalibrationCoords.last_x = cur_x;
+            m_CalibrationCoords.last_y = cur_y;
 
-            emit newPulse(RA_INC_DIR, m_LastPulse);
+            emit newPulse(RA_INC_DIR, m_CalibrationParams.last_pulse);
 
-            ra_iterations++;
+            m_CalibrationParams.ra_iterations++;
         }
     }
         break;
@@ -484,45 +485,50 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
         double cur_x, cur_y;
         pmath->getStarScreenPosition(&cur_x, &cur_y);
 
-        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration #" << ra_iterations << ": STAR " << cur_x << "," << cur_y;
-        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration " << ra_iterations << " Direction: RA_DEC_DIR" << " Duration: " << m_LastPulse << " ms.";
+        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration #" << m_CalibrationParams.ra_iterations << ": STAR " << cur_x << "," << cur_y;
+        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration " << m_CalibrationParams.ra_iterations << " Direction: RA_DEC_DIR" << " Duration: " << m_CalibrationParams.last_pulse << " ms.";
 
-        Vector star_pos = Vector(cur_x, cur_y, 0) - Vector(start_x1, start_y1, 0);
+        Vector star_pos = Vector(cur_x, cur_y, 0) - Vector(m_CalibrationCoords.start_x1, m_CalibrationCoords.start_y1, 0);
         star_pos.y      = -star_pos.y;
         star_pos        = star_pos * ROT_Z;
 
         qCDebug(KSTARS_EKOS_GUIDE) << "Star x pos is " << star_pos.x << " from original point.";
 
+        if (m_CalibrationCoords.ra_distance == 0.0)
+            m_CalibrationCoords.ra_distance = star_pos.x;
+
         // start point reached... so exit
         if (star_pos.x < 1.5)
         {
             pmath->performProcessing();
 
-            m_RATotalPulse += m_LastPulse;
-            m_LastPulse = Options::calibrationPulseDuration();
+            m_CalibrationParams.ra_total_pulse += m_CalibrationParams.last_pulse;
+            m_CalibrationParams.last_pulse = Options::calibrationPulseDuration();
             axis_calibration_complete = true;
         }
-        else if (fabs(cur_x-last_x) < 0.5 && fabs(cur_y-last_y) < 0.5)
+        // If we'not moving much, try increasing pulse to 200% to clear any backlash
+        // Also increase pulse width if we are going FARTHER and not back to our original position
+        else if ( (fabs(cur_x-m_CalibrationCoords.last_x) < 0.5 && fabs(cur_y-m_CalibrationCoords.last_y) < 0.5) || star_pos.x > m_CalibrationCoords.ra_distance)
         {
             // Increase pulse by 200%
-            m_LastPulse = Options::calibrationPulseDuration()*2;
+            m_CalibrationParams.last_pulse = Options::calibrationPulseDuration()*2;
         }
         else
         {
-            m_RATotalPulse += m_LastPulse;
-            m_LastPulse = Options::calibrationPulseDuration();
+            m_CalibrationParams.ra_total_pulse += m_CalibrationParams.last_pulse;
+            m_CalibrationParams.last_pulse = Options::calibrationPulseDuration();
         }
-        last_x = cur_x;
-        last_y = cur_y;
+        m_CalibrationCoords.last_x = cur_x;
+        m_CalibrationCoords.last_y = cur_y;
 
         //----- Z-check end -----
 
         if (axis_calibration_complete == false)
         {
-            if (ra_iterations < turn_back_time)
+            if (m_CalibrationParams.ra_iterations < m_CalibrationParams.turn_back_time)
             {
-                emit newPulse(RA_DEC_DIR, m_LastPulse);
-                ra_iterations++;
+                emit newPulse(RA_DEC_DIR, m_CalibrationParams.last_pulse);
+                m_CalibrationParams.ra_iterations++;
                 break;
             }
 
@@ -534,7 +540,7 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
                               "backlash problems...",
                               "GUIDE_RA: Scope cannot reach the start point after %1 iterations. Possible mount or "
                               "backlash problems...",
-                              ra_iterations));
+                              m_CalibrationParams.ra_iterations));
 
             KSNotification::event(QLatin1String("CalibrationFailed"), i18n("Guiding calibration failed with errors"), KSNotification::EVENT_ALERT);
             reset();
@@ -544,23 +550,23 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
         if (ra_only == false)
         {
             calibrationStage = CAL_DEC_INC;
-            start_x2         = cur_x;
-            start_y2         = cur_y;
+            m_CalibrationCoords.start_x2         = cur_x;
+            m_CalibrationCoords.start_y2         = cur_y;
 
-            last_x = cur_x;
-            last_y = cur_y;
+            m_CalibrationCoords.last_x = cur_x;
+            m_CalibrationCoords.last_y = cur_y;
 
-            qCDebug(KSTARS_EKOS_GUIDE) << "Start X2 " << start_x2 << " start Y2 " << start_y2;
+            qCDebug(KSTARS_EKOS_GUIDE) << "Start X2 " << m_CalibrationCoords.start_x2 << " start Y2 " << m_CalibrationCoords.start_y2;
 
             emit newPulse(DEC_INC_DIR, Options::calibrationPulseDuration());
 
-            dec_iterations++;
+            m_CalibrationParams.dec_iterations++;
 
             emit newLog(i18n("DEC drifting forward..."));
             break;
         }
         // calc orientation
-        if (pmath->calculateAndSetReticle1D(start_x1, start_y1, end_x1, end_y1, m_RATotalPulse))
+        if (pmath->calculateAndSetReticle1D(m_CalibrationCoords.start_x1, m_CalibrationCoords.start_y1, m_CalibrationCoords.end_x1, m_CalibrationCoords.end_y1, m_CalibrationParams.ra_total_pulse))
         {
             calibrationStage = CAL_IDLE;
 
@@ -591,33 +597,35 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
         double cur_x, cur_y;
         pmath->getStarScreenPosition(&cur_x, &cur_y);
 
-        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration #" << dec_iterations << ": STAR " << cur_x << "," << cur_y;
-        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration " << dec_iterations << " Direction: DEC_INC_DIR" << " Duration: " << m_LastPulse << " ms.";
+        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration #" << m_CalibrationParams.dec_iterations << ": STAR " << cur_x << "," << cur_y;
+        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration " << m_CalibrationParams.dec_iterations << " Direction: DEC_INC_DIR" << " Duration: " << m_CalibrationParams.last_pulse << " ms.";
 
-        if (dec_iterations >= auto_drift_time && (fabs(cur_x-start_x2) > 1.5 || fabs(cur_y-start_y2) > 1.5))
+        if (m_CalibrationParams.dec_iterations >= m_CalibrationParams.auto_drift_time && (fabs(cur_x-m_CalibrationCoords.start_x2) > 1.5 || fabs(cur_y-m_CalibrationCoords.start_y2) > 1.5))
         {
             calibrationStage = CAL_DEC_DEC;
 
-            m_DETotalPulse += m_LastPulse;
+            m_CalibrationParams.de_total_pulse += m_CalibrationParams.last_pulse;
 
-            end_x2 = cur_x;
-            end_y2 = cur_y;
+            m_CalibrationCoords.end_x2 = cur_x;
+            m_CalibrationCoords.end_y2 = cur_y;
 
-            last_x = cur_x;
-            last_y = cur_y;
+            m_CalibrationCoords.last_x = cur_x;
+            m_CalibrationCoords.last_y = cur_y;
 
             axis_calibration_complete = false;
 
-            qCDebug(KSTARS_EKOS_GUIDE) << "End X2 " << end_x2 << " End Y2 " << end_y2;
+            qCDebug(KSTARS_EKOS_GUIDE) << "End X2 " << m_CalibrationCoords.end_x2 << " End Y2 " << m_CalibrationCoords.end_y2;
 
-            phi   = pmath->calculatePhi(start_x2, start_y2, end_x2, end_y2);
-            ROT_Z = RotateZ(-M_PI * phi / 180.0); // derotates...
+            m_CalibrationParams.phi   = pmath->calculatePhi(m_CalibrationCoords.start_x2, m_CalibrationCoords.start_y2, m_CalibrationCoords.end_x2, m_CalibrationCoords.end_y2);
+            ROT_Z = RotateZ(-M_PI * m_CalibrationParams.phi / 180.0); // derotates...
 
-            emit newPulse(DEC_DEC_DIR, m_LastPulse);
+            m_CalibrationCoords.de_distance = 0;
+
+            emit newPulse(DEC_DEC_DIR, m_CalibrationParams.last_pulse);
             emit newLog(i18n("DEC drifting reverse..."));
-            dec_iterations++;
+            m_CalibrationParams.dec_iterations++;
         }
-        else if (dec_iterations > turn_back_time)
+        else if (m_CalibrationParams.dec_iterations > m_CalibrationParams.turn_back_time)
         {
             calibrationStage = CAL_ERROR;
 
@@ -627,7 +635,7 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
                               "or backlash problems...",
                               "GUIDE DEC: Scope cannot reach the start point after %1 iterations.\nPossible mount "
                               "or backlash problems...",
-                              dec_iterations));
+                              m_CalibrationParams.dec_iterations));
 
             KSNotification::event(QLatin1String("CalibrationFailed"),
                                  i18n("Guiding calibration failed with errors"), KSNotification::EVENT_ALERT);
@@ -635,22 +643,22 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
         }
         else
         {
-            if (fabs(cur_x-last_x) < 0.5 && fabs(cur_y-last_y) < 0.5)
+            if (fabs(cur_x-m_CalibrationCoords.last_x) < 0.5 && fabs(cur_y-m_CalibrationCoords.last_y) < 0.5)
             {
                 // Increase pulse by 200%
-                m_LastPulse = Options::calibrationPulseDuration()*2;
+                m_CalibrationParams.last_pulse = Options::calibrationPulseDuration()*2;
             }
             else
             {
-                m_DETotalPulse += m_LastPulse;
-                m_LastPulse = Options::calibrationPulseDuration();
+                m_CalibrationParams.de_total_pulse += m_CalibrationParams.last_pulse;
+                m_CalibrationParams.last_pulse = Options::calibrationPulseDuration();
             }
-            last_x = cur_x;
-            last_y = cur_y;
+            m_CalibrationCoords.last_x = cur_x;
+            m_CalibrationCoords.last_y = cur_y;
 
-            emit newPulse(DEC_INC_DIR, m_LastPulse);
+            emit newPulse(DEC_INC_DIR, m_CalibrationParams.last_pulse);
 
-            dec_iterations++;
+            m_CalibrationParams.dec_iterations++;
         }
     }
         break;
@@ -662,41 +670,46 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
         pmath->getStarScreenPosition(&cur_x, &cur_y);
 
         // Star position resulting from LAST guiding pulse to mount
-        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration #" << dec_iterations << ": STAR " << cur_x << "," << cur_y;
-        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration " << dec_iterations << " Direction: DEC_DEC_DIR" << " Duration: " << m_LastPulse << " ms.";
+        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration #" << m_CalibrationParams.dec_iterations << ": STAR " << cur_x << "," << cur_y;
+        qCDebug(KSTARS_EKOS_GUIDE) << "Iteration " << m_CalibrationParams.dec_iterations << " Direction: DEC_DEC_DIR" << " Duration: " << m_CalibrationParams.last_pulse << " ms.";
 
-        Vector star_pos = Vector(cur_x, cur_y, 0) - Vector(start_x2, start_y2, 0);
+        Vector star_pos = Vector(cur_x, cur_y, 0) - Vector(m_CalibrationCoords.start_x2, m_CalibrationCoords.start_y2, 0);
         star_pos.y      = -star_pos.y;
         star_pos        = star_pos * ROT_Z;
 
         qCDebug(KSTARS_EKOS_GUIDE) << "start Pos X " << star_pos.x << " from original point.";
 
+        // Keep track of distance
+        if (m_CalibrationCoords.de_distance == 0.0)
+            m_CalibrationCoords.de_distance = star_pos.x;
+
         // start point reached... so exit
         if (star_pos.x < 1.5)
         {
             pmath->performProcessing();
 
-            m_DETotalPulse += m_LastPulse;
-            m_LastPulse = Options::calibrationPulseDuration();
+            m_CalibrationParams.de_total_pulse += m_CalibrationParams.last_pulse;
+            m_CalibrationParams.last_pulse = Options::calibrationPulseDuration();
             axis_calibration_complete = true;
         }
-        else if (fabs(cur_x-last_x) < 0.5 && fabs(cur_y-last_y) < 0.5)
+        // Increase pulse if we're not moving much or if we are moving _away_ from target.
+        else if ( (fabs(cur_x-m_CalibrationCoords.last_x) < 0.5 && fabs(cur_y-m_CalibrationCoords.last_y) < 0.5) || star_pos.x > m_CalibrationCoords.de_distance)
         {
             // Increase pulse by 200%
-            m_LastPulse = Options::calibrationPulseDuration()*2;
+            m_CalibrationParams.last_pulse = Options::calibrationPulseDuration()*2;
         }
         else
         {
-            m_DETotalPulse += m_LastPulse;
-            m_LastPulse = Options::calibrationPulseDuration();
+            m_CalibrationParams.de_total_pulse += m_CalibrationParams.last_pulse;
+            m_CalibrationParams.last_pulse = Options::calibrationPulseDuration();
         }
 
         if (axis_calibration_complete == false)
         {
-            if (dec_iterations < turn_back_time)
+            if (m_CalibrationParams.dec_iterations < m_CalibrationParams.turn_back_time)
             {
-                emit newPulse(DEC_DEC_DIR, m_LastPulse);
-                dec_iterations++;
+                emit newPulse(DEC_DEC_DIR, m_CalibrationParams.last_pulse);
+                m_CalibrationParams.dec_iterations++;
                 break;
             }
 
@@ -708,7 +721,7 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
                               "or backlash problems...",
                               "Guide DEC: Scope cannot reach the start point after %1 iterations.\nPossible mount "
                               "or backlash problems...",
-                              dec_iterations));
+                              m_CalibrationParams.dec_iterations));
 
             KSNotification::event(QLatin1String("CalibrationFailed"),
                                  i18n("Guiding calibration failed with errors"),KSNotification::EVENT_ALERT);
@@ -718,8 +731,8 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
 
         bool swap_dec = false;
         // calc orientation
-        if (pmath->calculateAndSetReticle2D(start_x1, start_y1, end_x1, end_y1, start_x2, start_y2, end_x2, end_y2,
-                                            &swap_dec, m_RATotalPulse, m_DETotalPulse))
+        if (pmath->calculateAndSetReticle2D(m_CalibrationCoords.start_x1, m_CalibrationCoords.start_y1, m_CalibrationCoords.end_x1, m_CalibrationCoords.end_y1, m_CalibrationCoords.start_x2, m_CalibrationCoords.start_y2, m_CalibrationCoords.end_x2, m_CalibrationCoords.end_y2,
+                                            &swap_dec, m_CalibrationParams.ra_total_pulse, m_CalibrationParams.de_total_pulse))
         {
             calibrationStage = CAL_IDLE;
             //fillInterface();
@@ -848,14 +861,14 @@ bool InternalGuider::processGuiding()
 
     // On first frame, center the box (reticle) around the star so we do not start with an offset the results in
     // unnecessary guiding pulses.
-    if (isFirstFrame)
+    if (m_isFirstFrame)
     {
         if (state == GUIDE_GUIDING)
         {
             Vector star_pos = pmath->findLocalStarPosition();
             pmath->setReticleParameters(star_pos.x, star_pos.y, -1);
         }
-        isFirstFrame = false;
+        m_isFirstFrame = false;
     }
 
     // calc math. it tracks square
@@ -872,24 +885,42 @@ bool InternalGuider::processGuiding()
     bool sendPulses = true;
 
     // If within 95% of max pulse repeatedly, let's abort
-    if (out->pulse_length[GUIDE_RA] >= (0.95 * Options::rAMaximumPulse()) ||
-        out->pulse_length[GUIDE_DEC] >= (0.95 * Options::dECMaximumPulse()))
+//    if (out->pulse_length[GUIDE_RA] >= (0.95 * Options::rAMaximumPulse()) ||
+//        out->pulse_length[GUIDE_DEC] >= (0.95 * Options::dECMaximumPulse()))
+//    {
+//        // Stop sending pulses in case we are guiding and we already sent one high pulse before
+//        // since we do not want to stray too much off the target to purse the guiding star
+//        if (state == GUIDE_GUIDING && m_highPulseCounter > 0)
+//            sendPulses = false;
+//        m_highPulseCounter++;
+//    }
+//    else
+//        m_highPulseCounter=0;
+
+    double delta_rms = sqrt(out->delta[GUIDE_RA]*out->delta[GUIDE_RA] + out->delta[GUIDE_DEC]*out->delta[GUIDE_DEC]);
+    if (delta_rms > Options::guideMaxDeltaRMS())
     {
-        // Stop sending pulses in case we are guiding and we already sent one high pulse before
-        // since we do not want to stray too much off the target to purse the guiding star
-        if (state == GUIDE_GUIDING && m_highPulseCounter > 0)
+        // Stop sending pulses on the 3rd time the delta RMS is high
+        // so that we don't stray too far off the main target.
+        if (state == GUIDE_GUIDING && m_highRMSCounter > 2)
             sendPulses = false;
-        m_highPulseCounter++;
+        m_highRMSCounter++;
     }
     else
-        m_highPulseCounter=0;
+        m_highRMSCounter=0;
 
-    uint8_t abortThreshold = (state == GUIDE_DITHERING) ? MAX_COMBINTED_PULSE_LIMITS * 3 : MAX_COMBINTED_PULSE_LIMITS;
-    if (m_starLostCounter+m_highPulseCounter > abortThreshold)
+    uint8_t abortStarLostThreshold = (state == GUIDE_DITHERING) ? MAX_LOST_STAR_THRESHOLD * 3 : MAX_LOST_STAR_THRESHOLD;
+    uint8_t abortRMSThreshold = (state == GUIDE_DITHERING) ? MAX_RMS_THRESHOLD * 3 : MAX_RMS_THRESHOLD;
+    if (m_starLostCounter > abortStarLostThreshold || m_highRMSCounter > abortRMSThreshold)
     {
         qCDebug(KSTARS_EKOS_GUIDE) << "m_starLostCounter" << m_starLostCounter
-                                   << "m_highPulseCounter" << m_highPulseCounter;
-        emit newLog(i18n("Lost track of the guide star. Searching for guide stars..."));
+                                   << "m_highRMSCounter" << m_highRMSCounter
+                                   << "delta_rms" << delta_rms;
+
+        if (m_starLostCounter > abortStarLostThreshold)
+            emit newLog(i18n("Lost track of the guide star. Searching for guide stars..."));
+        else
+            emit newLog(i18n("Delta RMS threshold value exceeded. Searching for guide stars..."));
 
         reacquireTimer.start();
         rememberState = state;
@@ -1017,12 +1048,12 @@ bool InternalGuider::processImageGuiding()
 
 bool InternalGuider::isImageGuideEnabled() const
 {
-    return imageGuideEnabled;
+    return m_ImageGuideEnabled;
 }
 
 void InternalGuider::setImageGuideEnabled(bool value)
 {
-    imageGuideEnabled = value;
+    m_ImageGuideEnabled = value;
 
     pmath->setImageGuideEnabled(value);
 }
@@ -1169,8 +1200,9 @@ bool InternalGuider::reacquire()
     bool rc = selectAutoStar();
     if (rc)
     {
-        m_highPulseCounter=m_starLostCounter=0;
-        isFirstFrame = true;
+        m_highRMSCounter=m_starLostCounter=0;
+        m_isFirstFrame = true;
+        pmath->reset();
         // If we were in the process of dithering, wait until settle and resume
         if (rememberState == GUIDE_DITHERING)
         {
