@@ -194,13 +194,16 @@ void Mount::setTelescope(ISD::GDInterface *newTelescope)
 
     syncTelescopeInfo();
 
-    // Send inital status
+    // Send initial status
     lastStatus = currentTelescope->getStatus();
     emit newStatus(lastStatus);
 }
 
 void Mount::syncTelescopeInfo()
 {
+    if (currentTelescope == nullptr || currentTelescope->isConnected() == false)
+        return;
+
     INumberVectorProperty *nvp = currentTelescope->getBaseDevice()->getNumber("TELESCOPE_INFO");
 
     if (nvp)
@@ -1124,7 +1127,7 @@ void Mount::startParkTimer()
     qint64 parkSeconds = parkTime.msecsTo(KStarsData::Instance()->lt());
     if (parkSeconds > 0)
     {
-        appendLogText(i18n("Parking time cannot be in the past!"));
+        appendLogText(i18n("Parking time cannot be in the past."));
         return;
     }
 
@@ -1136,7 +1139,7 @@ void Mount::startParkTimer()
         return;
     }
 
-    appendLogText(i18n("Caution! Do not use Auto Park while scheduler is active."));
+    appendLogText(i18n("Caution: do not use Auto Park while scheduler is active."));
 
     autoParkTimer.setInterval(parkSeconds);
     autoParkTimer.start();
