@@ -205,6 +205,32 @@ class Scheduler : public QWidget, public Ui::Scheduler
 
     /** @}*/
 
+    /** @{ */
+  private:
+    /** @internal Safeguard flag to avoid registering signals from widgets multiple times.
+     */
+    bool jobChangesAreWatched { false };
+
+  protected:
+    /** @internal Enables signal watch on SchedulerJob form values in order to apply changes to current job.
+      * @param enable is the toggle flag, true to watch for changes, false to ignore them.
+      */
+    void watchJobChanges(bool enable);
+
+    /** @internal Marks the currently selected SchedulerJob as modified change.
+     *
+     * This triggers job re-evaluation.
+     * Next time save button is invoked, the complete content is written to disk.
+      */
+    void setDirty();
+    /** @} */
+
+  protected:
+    /** @internal Associate job table cells on a row to the corresponding SchedulerJob.
+     * @param row is an integer indexing the row to associate cells from, and also the index of the job in the job list..
+     */
+    void setJobStatusCells(int row);
+
   protected slots:
 
     /**
@@ -254,14 +280,37 @@ class Scheduler : public QWidget, public Ui::Scheduler
          */
     void removeJob();
 
+    /**
+         * @brief setJobAddApply Set first button state to add new job or apply changes.
+         */
+    void setJobAddApply(bool add_mode);
+
+    /**
+         * @brief setJobManipulation Enable or disable job manipulation buttons.
+         */
+    void setJobManipulation(bool enable);
+
+    /**
+         * @brief clickQueueTable Update UI state when the job list is clicked once.
+         */
+    void clickQueueTable(QModelIndex index);
+
+    /**
+         * @brief moveJobUp Move the selected job up in the job list.
+         */
+    void moveJobUp();
+
+    /**
+        * @brief moveJobDown Move the selected job down in the list.
+        */
+    void moveJobDown();
+
     void toggleScheduler();
     void pause();
     void save();
     void saveAs();
     void load();
 
-    void resetJobState(QModelIndex i);
-
     void resetJobEdit();
 
     /**
@@ -295,16 +344,6 @@ class Scheduler : public QWidget, public Ui::Scheduler
          */
     void checkProcessExit(int exitCode);
 
-    /**
-         * @brief watchJobChanges Watch any changes in form values and apply changes to current job selection or ignore any changes
-         * @param enable True to watch changes and apply them to current job, false to ignore changes
-         */
-    void watchJobChanges(bool enable);
-    /**
-         * @brief setDirty Call it to mark the Ekos Scheduler List for change. Next time save button is invoked, the complete content is written to disk.
-         */
-    void setDirty();
-
     /**
          * @brief resumeCheckStatus If the scheduler primary loop was suspended due to weather or sleep event, resume it again.
          */
@@ -553,7 +592,11 @@ class Scheduler : public QWidget, public Ui::Scheduler
 
     bool isWeatherOK(SchedulerJob *job);
 
-    void updateCompletedJobsCount();
+    /**
+        * @brief updateCompletedJobsCount For each scheduler job, examine sequence job storage and count captures.
+        * @param forced forces recounting captures unconditionally if true, else only IDLE, EVALUATION or new jobs are examined.
+        */
+    void updateCompletedJobsCount(bool forced = false);
 
     SequenceJob *processJobInfo(XMLEle *root, SchedulerJob *schedJob);
     bool loadSequenceQueue(const QString &fileURL, SchedulerJob *schedJob, QList<SequenceJob *> &jobs,
