@@ -306,10 +306,14 @@ class SchedulerJob
 
     /** @brief The map of capture counts for this job, keyed by its capture storage signatures. */
     /** @{ */
-    QMap<QString, uint16_t> getCapturedFramesMap() const { return capturedFramesMap; }
-    void setCapturedFramesMap(const QMap<QString, uint16_t> &value);
+    typedef QMap<QString, uint16_t> CapturedFramesMap;
+    const CapturedFramesMap& getCapturedFramesMap() const { return capturedFramesMap; }
+    void setCapturedFramesMap(const CapturedFramesMap &value);
     /** @} */
 
+    /** @brief Refresh all cells connected to this SchedulerJob. */
+    void updateJobCell();
+
     /** @brief Resetting a job to original values:
      * - idle state and stage
      * - original startup, none if asap, else user original setting
@@ -395,9 +399,6 @@ private:
     QTableWidgetItem *scoreCell { nullptr };
     /** @} */
 
-    /** @internal General cell refresh. */
-    void updateJobCell();
-
     int score { 0 };
     int16_t culminationOffset { 0 };
     uint8_t priority { 10 };
