@@ -187,9 +187,13 @@ void FITSHistogram::constructHistogram()
     }
 
     // Cumulative Frequency
-    for (int i = 0; i < binCount; i++)
-        for (int j = 0; j <= i; j++)
-            cumulativeFrequency[i] += r_frequency[j];
+    int j = 0;
+    double val = 0;
+    for (int i = 0; i < binCount; i++) {
+        val += r_frequency[j++];
+        cumulativeFrequency.replace(i, val);
+    }
+
 
     if (image_data->getNumOfChannels() == 1)
     {
@@ -544,7 +548,7 @@ bool FITSHistogramCommand::calculateDelta(const uint8_t *buffer)
     FITSData *image_data = tab->getView()->getImageData();
 
     uint8_t *image_buffer    = image_data->getImageBuffer();
-    int totalPixels          = image_data->getSize() * image_data->getNumOfChannels();
+    int totalPixels          = image_data->getSamplesPerChannel() * image_data->getNumOfChannels();
     unsigned long totalBytes = totalPixels * image_data->getBytesPerPixel();
 
     auto *raw_delta = new uint8_t[totalBytes];
@@ -592,7 +596,7 @@ bool FITSHistogramCommand::reverseDelta()
     FITSData *image_data  = image->getImageData();
     uint8_t *image_buffer = (image_data->getImageBuffer());
 
-    unsigned int size = image_data->getSize();
+    unsigned int size = image_data->getSamplesPerChannel();
     int channels      = image_data->getNumOfChannels();
 
     int totalPixels          = size * channels;
@@ -640,7 +644,7 @@ void FITSHistogramCommand::redo()
     FITSData *image_data = image->getImageData();
 
     uint8_t *image_buffer = image_data->getImageBuffer();
-    unsigned int size     = image_data->getSize();
+    unsigned int size     = image_data->getSamplesPerChannel();
     int channels          = image_data->getNumOfChannels();
     int BBP               = image_data->getBytesPerPixel();
 
