@@ -15,6 +15,7 @@
 #include "driverinfo.h"
 #include "deviceinfo.h"
 #include "imageviewer.h"
+#include "indi_debug.h"
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "Options.h"
@@ -23,8 +24,6 @@
 #include <QImageReader>
 #include <QStatusBar>
 
-#include "indi_debug.h"
-
 namespace ISD
 {
 GDSetCommand::GDSetCommand(INDI_PROPERTY_TYPE inPropertyType, const QString &inProperty, const QString &inElement,
@@ -47,10 +46,6 @@ GenericDevice::GenericDevice(DeviceInfo &idv)
     dType = KSTARS_UNKNOWN;
 }
 
-GenericDevice::~GenericDevice()
-{
-}
-
 const char *GenericDevice::getDeviceName()
 {
     return baseDevice->getDeviceName();
@@ -226,6 +221,7 @@ void GenericDevice::processNumber(INumberVectorProperty *nvp)
             elev = np->value;
 
         GeoLocation *geo = KStars::Instance()->data()->geo();
+        std::unique_ptr<GeoLocation> tempGeo;
 
         QString newLocationName;
         if (getDriverInterface() & INDI::BaseDevice::GPS_INTERFACE)
@@ -237,7 +233,8 @@ void GenericDevice::processNumber(INumberVectorProperty *nvp)
         {
             double TZ0 = geo->TZ0();
             TimeZoneRule *rule = geo->tzrule();
-            geo = new GeoLocation(lng, lat, newLocationName, "", "", TZ0, rule, elev);
+            tempGeo.reset(new GeoLocation(lng, lat, newLocationName, "", "", TZ0, rule, elev));
+            geo = tempGeo.get();
         }
         else
         {
@@ -245,7 +242,7 @@ void GenericDevice::processNumber(INumberVectorProperty *nvp)
             geo->setLat(lat);
         }
 
-        qCInfo(KSTARS_INDI) << "Setting location from device:" << getDeviceName() << "Longitude:" << lng.toDMSString() << "Latitude:" << lat.toDMSString();
+        qCInfo(KSTARS_INDI) << "Setting location from device:" << deviceName << "Longitude:" << lng.toDMSString() << "Latitude:" << lat.toDMSString();
 
         KStars::Instance()->data()->setLocation(*geo);
     }
@@ -928,10 +925,6 @@ ST4::ST4(INDI::BaseDevice *bdv, ClientManager *cm)
     clientManager = cm;
 }
 
-ST4::~ST4()
-{
-}
-
 const char *ST4::getDeviceName()
 {
     return baseDevice->getDeviceName();
