@@ -150,7 +150,7 @@ void Telescope::registerProperty(INDI::Property *prop)
 
 void Telescope::processNumber(INumberVectorProperty *nvp)
 {
-    if (!strcmp(nvp->name, "EQUATORIAL_EOD_COORD"))
+    if (!strcmp(nvp->name, "EQUATORIAL_EOD_COORD") || !strcmp(nvp->name, "EQUATORIAL_COORD"))
     {
         INumber *RA  = IUFindNumber(nvp, "RA");
         INumber *DEC = IUFindNumber(nvp, "DEC");
@@ -160,6 +160,15 @@ void Telescope::processNumber(INumberVectorProperty *nvp)
 
         currentCoord.setRA(RA->value);
         currentCoord.setDec(DEC->value);
+
+        // If J2000, connvert it to JNow
+        if (!strcmp(nvp->name, "EQUATORIAL_COORD"))
+        {
+            currentCoord.setRA0(RA->value);
+            currentCoord.setDec0(DEC->value);
+            currentCoord.apparentCoord(static_cast<long double>(J2000), KStars::Instance()->data()->ut().djd());
+        }
+
         currentCoord.EquatorialToHorizontal(KStars::Instance()->data()->lst(),
                                             KStars::Instance()->data()->geo()->lat());
 
@@ -565,8 +574,8 @@ bool Telescope::sendCoords(SkyPoint *ScopeTarget)
         if (!DecEle)
             return false;
 
-        if (useJ2000)
-            ScopeTarget->apparentCoord(KStars::Instance()->data()->ut().djd(), (long double)J2000);
+        //if (useJ2000)
+            //ScopeTarget->apparentCoord( KStars::Instance()->data()->ut().djd(), static_cast<long double>(J2000));
 
         currentRA  = RAEle->value;
         currentDEC = DecEle->value;
@@ -631,12 +640,37 @@ bool Telescope::sendCoords(SkyPoint *ScopeTarget)
 
     if (EqProp)
     {
-        RAEle->value  = ScopeTarget->ra().Hours();
-        DecEle->value = ScopeTarget->dec().Degrees();
+        dms ra, de;
+
+        if (useJ2000)
+        {
+            // If we have invalid DEC, then convert coords to J2000
+            if (ScopeTarget->dec0().Degrees() == 180.0)
+            {
+               ScopeTarget->setRA0(ScopeTarget->ra());
+               ScopeTarget->setDec0(ScopeTarget->dec());
+               ScopeTarget->apparentCoord( KStars::Instance()->data()->ut().djd(), static_cast<long double>(J2000));
+               ra = ScopeTarget->ra();
+               de = ScopeTarget->dec();
+            }
+            else
+            {
+                ra = ScopeTarget->ra0();
+                de = ScopeTarget->dec0();
+            }
+        }
+        else
+        {
+            ra = ScopeTarget->ra();
+            de = ScopeTarget->dec();
+        }
+
+        RAEle->value  = ra.Hours();
+        DecEle->value = de.Degrees();
         clientManager->sendNewNumber(EqProp);
 
-        qCDebug(KSTARS_INDI) << "ISD:Telescope sending coords RA:" << ScopeTarget->ra().toHMSString() <<
-                                "(" << RAEle->value << ") DE:" << ScopeTarget->dec().toDMSString() <<
+        qCDebug(KSTARS_INDI) << "ISD:Telescope sending coords RA:" << ra.toHMSString() <<
+                                "(" << RAEle->value << ") DE:" << de.toDMSString() <<
                                 "(" << DecEle->value << ")";
 
         RAEle->value  = currentRA;
