@@ -1,11 +1,11 @@
-/** *************************************************************************
+/***************************************************************************
                           kstarslite.cpp  -  K Desktop Planetarium
                              -------------------
     begin                : 30/04/2016
     copyright            : (C) 2016 by Artem Fedoskin
     email                : afedoskin3@gmail.com
  ***************************************************************************/
-/** *************************************************************************
+/***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,30 +15,28 @@
  ***************************************************************************/
 
 #include "kstarslite.h"
-#include "skymaplite.h"
-#include "kstarsdata.h"
-#include <QQmlContext>
-#include <QGuiApplication>
-#include <QQuickStyle>
-#include <QSurfaceFormat>
-#include "kstarslite/imageprovider.h"
+
 #include "klocalizedcontext.h"
-#include "ksplanetbase.h"
-#include <QScreen>
-
-#include "indi/clientmanagerlite.h"
-
 #include "kspaths.h"
-
-//Dialogs
+#include "ksplanetbase.h"
+#include "kstarsdata.h"
+#include "ksutils.h"
+#include "Options.h"
+#include "skymaplite.h"
+#include "version.h"
+#include "indi/clientmanagerlite.h"
+#include "kstarslite/imageprovider.h"
 #include "kstarslite/dialogs/finddialoglite.h"
 #include "kstarslite/dialogs/detaildialoglite.h"
 #include "kstarslite/dialogs/locationdialoglite.h"
 
-#include "Options.h"
-#include "ksutils.h"
+#include <QGuiApplication>
+#include <QQmlContext>
+#include <QQuickStyle>
+#include <QScreen>
+#include <QSurfaceFormat>
 
-KStarsLite *KStarsLite::pinstance = 0;
+KStarsLite *KStarsLite::pinstance = nullptr;
 
 KStarsLite::KStarsLite(bool doSplash, bool startClock, const QString &startDateString)
 {
@@ -106,13 +104,21 @@ KStarsLite::KStarsLite(bool doSplash, bool startClock, const QString &startDateS
     m_RootObject = m_Engine.rootObjects()[0];
     m_clientManager->setIndiControlPage(*m_RootObject->findChild<QObject*>("indiControlPanel"));
 
+    // Set the About information
+    QObject *aboutDialog = m_RootObject->findChild<QObject*>("aboutDialog");
+
+    aboutDialog->setProperty("versionText", i18n("Version: %1", QStringLiteral(KSTARS_VERSION)));
+    aboutDialog->setProperty("buildText", i18n("Build: %1", QStringLiteral(KSTARS_BUILD_TS)));
+    aboutDialog->setProperty("teamText", QString("2001-" + QString::number(QDate::currentDate().year()) + i18n("(c), The KStars Team")));
+    aboutDialog->setProperty("licenseText", i18n("License: GPLv2"));
+
     QQuickItem *skyMapLiteWrapper = m_RootObject->findChild<QQuickItem *>("skyMapLiteWrapper");
 
     m_SkyMapLite->initialize(skyMapLiteWrapper);
     m_detailDialogLite->initialize();
 
-    m_imgProvider = new ImageProvider;
-    m_Engine.addImageProvider(QLatin1String("images"), m_imgProvider);
+    m_imgProvider.reset(new ImageProvider);
+    m_Engine.addImageProvider(QLatin1String("images"), m_imgProvider.get());
 
 #ifdef Q_OS_ANDROID
     QQuickWindow *mainWindow = static_cast<QQuickWindow *>(m_Engine.rootObjects()[0]);
@@ -161,7 +167,6 @@ KStarsLite::KStarsLite(bool doSplash, bool startClock, const QString &startDateS
 
 KStarsLite::~KStarsLite()
 {
-    delete m_imgProvider;
 }
 
 QQuickWindow *KStarsLite::getMainWindow()
