@@ -15,18 +15,19 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef COMETSCOMPONENT_H
-#define COMETSCOMPONENT_H
+#pragma once
 
-class SkyLabeler;
-
-#include "solarsystemlistcomponent.h"
 #include "ksparser.h"
+#include "solarsystemlistcomponent.h"
+
 #include <QList>
 
 class FileDownloader;
+class SkyLabeler;
 
-/** @class CometsComponent
+/**
+ * @class CometsComponent
+ *
  * This class encapsulates the Comets
  *
  * @author Jason Harris
@@ -37,12 +38,15 @@ class CometsComponent : public QObject, public SolarSystemListComponent
     Q_OBJECT
 
   public:
-    /** @short Default constructor.
-         * @p parent pointer to the parent SolarSystemComposite
-         */
+    /**
+     * @short Default constructor.
+     *
+     * @p parent pointer to the parent SolarSystemComposite
+     */
     explicit CometsComponent(SolarSystemComposite *parent);
 
-    ~CometsComponent() override;
+    virtual ~CometsComponent() override = default;
+
     bool selected() override;
     void draw(SkyPainter *skyp) override;
     void updateDataFile();
@@ -53,7 +57,6 @@ class CometsComponent : public QObject, public SolarSystemListComponent
 
   private:
     void loadData();
-    FileDownloader *downloadJob;
-};
 
-#endif
+    FileDownloader *downloadJob { nullptr };
+};
