@@ -111,8 +111,7 @@ class SkyComponent
      */
     explicit SkyComponent(SkyComposite *parent = nullptr);
 
-    /** @short Destructor */
-    virtual ~SkyComponent();
+    virtual ~SkyComponent() = default;
 
     /**
      * @short Draw the object on the SkyMap
@@ -196,7 +195,6 @@ class SkyComponent
 
     inline QVector<QPair<QString, const SkyObject *>> &objectLists(int type) { return getObjectLists()[type]; }
 
-  protected:
     void removeFromNames(const SkyObject *obj);
     void removeFromLists(const SkyObject *obj);
 
