@@ -182,10 +182,6 @@ SkyMapComposite::SkyMapComposite(SkyComposite *parent) : SkyComposite(parent), m
     connect(this, SIGNAL(progressText(QString)), KStarsData::Instance(), SIGNAL(progressText(QString)));
 }
 
-SkyMapComposite::~SkyMapComposite()
-{
-}
-
 void SkyMapComposite::update(KSNumbers *num)
 {
     //printf("updating SkyMapComposite\n");
@@ -365,12 +361,7 @@ void SkyMapComposite::draw(SkyPainter *skyp)
     m_DeepSky->drawLabels();
 
     m_ObservingList->pen = QPen(QColor(data->colorScheme()->colorNamed("ObsListColor")), 1.);
-    if (KStars::Instance() && !m_ObservingList->list)
-        m_ObservingList->list.reset(new SkyObjectList(KSUtils::makeVanillaPointerList(
-            KStarsData::Instance()
-                ->observingList()
-                ->sessionList()))); // Make sure we never delete the pointers in m_ObservingList->list!
-
+    m_ObservingList->list2 = KStarsData::Instance()->observingList()->sessionList();
     m_ObservingList->draw(skyp);
 
     m_Flags->draw(skyp);
@@ -448,10 +439,10 @@ SkyObject *SkyMapComposite::objectNearest(SkyPoint *p, double &maxrad)
         oBest = oTry;
     }    
 
-    for (int i = 0; i < m_DeepStars.size(); ++i)
+    for (auto &star : m_DeepStars)
     {
         rTry = maxrad;
-        oTry = m_DeepStars.at(i)->objectNearest(p, rTry);
+        oTry = star->objectNearest(p, rTry);
         if (rTry < rBest)
         {
             rBest = rTry;
