@@ -28,60 +28,64 @@ class KSNumbers;
 class KSPopupMenu;
 struct StarData;
 
-/** @class StarObject
-        *This is a subclass of SkyObject.  It adds the Spectral type, and flags
-        *for variability and multiplicity.
-        *For stars, the primary name (n) is the latin name (e.g., "Betelgeuse").  The
-        *secondary name (n2) is the genetive name (e.g., "alpha Orionis").
-        *@short subclass of SkyObject specialized for stars.
-        *@author Thomas Kabelmann
-        *@version 1.0
-        */
-
+/**
+ * @class StarObject
+ *
+ * This is a subclass of SkyObject.  It adds the Spectral type, and flags
+ * for variability and multiplicity.
+ * For stars, the primary name (n) is the latin name (e.g., "Betelgeuse").  The
+ * secondary name (n2) is the genetive name (e.g., "alpha Orionis").
+ * @short subclass of SkyObject specialized for stars.
+ *
+ * @author Thomas Kabelmann
+ * @version 1.0
+ */
 class StarObject : public SkyObject
 {
   public:
-    /** @short returns the reindex interval (in centuries!) for the given
-         * magnitude of proper motion (in milliarcsec/year).  ASSUMING a
-         * 25 arc-minute margin for proper motion.
-         */
+    /**
+     * @short returns the reindex interval (in centuries!) for the given
+     * magnitude of proper motion (in milliarcsec/year).  ASSUMING a
+     * 25 arc-minute margin for proper motion.
+     */
     static double reindexInterval(double pm);
 
     /**
-            *Constructor.  Sets sky coordinates, magnitude, latin name, genetive name, and
-            *spectral type.
-            *@param r Right Ascension
-            *@param d Declination
-            *@param m magnitude
-            *@param n common name
-            *@param n2 genetive name
-            *@param sptype Spectral Type
-            *@param pmra Proper motion in RA direction [mas/yr]
-            *@param pmdec Proper motion in Dec direction [mas/yr]
-            *@param par Parallax angle [mas]
-            *@param mult Multiplicity flag (false=dingle star; true=multiple star)
-            *@param var Variability flag (true if star is a known periodic variable)
-            *@param hd Henry Draper Number
-            */
+     * Constructor.  Sets sky coordinates, magnitude, latin name, genetive name, and spectral type.
+     *
+     * @param r Right Ascension
+     * @param d Declination
+     * @param m magnitude
+     * @param n common name
+     * @param n2 genetive name
+     * @param sptype Spectral Type
+     * @param pmra Proper motion in RA direction [mas/yr]
+     * @param pmdec Proper motion in Dec direction [mas/yr]
+     * @param par Parallax angle [mas]
+     * @param mult Multiplicity flag (false=dingle star; true=multiple star)
+     * @param var Variability flag (true if star is a known periodic variable)
+     * @param hd Henry Draper Number
+     */
     explicit StarObject(dms r = dms(0.0), dms d = dms(0.0), float m = 0.0, const QString &n = QString(),
                         const QString &n2 = QString(), const QString &sptype = "--", double pmra = 0.0,
                         double pmdec = 0.0, double par = 0.0, bool mult = false, bool var = false, int hd = 0);
     /**
-            *Constructor.  Sets sky coordinates, magnitude, latin name, genetive name, and
-            *spectral type.  Differs from above function only in data type of RA and Dec.
-            *@param r Right Ascension
-            *@param d Declination
-            *@param m magnitude
-            *@param n common name
-            *@param n2 genetive name
-            *@param sptype Spectral Type
-            *@param pmra Proper motion in RA direction [mas/yr]
-            *@param pmdec Proper motion in Dec direction [mas/yr]
-            *@param par Parallax angle [mas]
-            *@param mult Multiplicity flag (false=dingle star; true=multiple star)
-            *@param var Variability flag (true if star is a known periodic variable)
-            *@param hd Henry Draper Number
-            */
+     * Constructor.  Sets sky coordinates, magnitude, latin name, genetive name, and
+     * spectral type.  Differs from above function only in data type of RA and Dec.
+     *
+     * @param r Right Ascension
+     * @param d Declination
+     * @param m magnitude
+     * @param n common name
+     * @param n2 genetive name
+     * @param sptype Spectral Type
+     * @param pmra Proper motion in RA direction [mas/yr]
+     * @param pmdec Proper motion in Dec direction [mas/yr]
+     * @param par Parallax angle [mas]
+     * @param mult Multiplicity flag (false=dingle star; true=multiple star)
+     * @param var Variability flag (true if star is a known periodic variable)
+     * @param hd Henry Draper Number
+     */
     StarObject(double r, double d, float m = 0.0, const QString &n = QString(), const QString &n2 = QString(),
                const QString &sptype = "--", double pmra = 0.0, double pmdec = 0.0, double par = 0.0, bool mult = false,
                bool var = false, int hd = 0);
@@ -93,34 +97,34 @@ class StarObject : public SkyObject
     StarObject(const StarObject &o);
 
     /** Destructor. (Empty) */
-    ~StarObject() override {}
+    ~StarObject() override = default;
 
     /**
-         *@short  Initializes a StarObject to given data
-         *
-         * This is almost like the StarObject constructor itself, but it avoids
-         * setting up name, gname etc for unnamed stars. If called instead of the
-         * constructor, this method will be much faster for unnamed stars
-         *
-         *@param  stardata  Pointer to starData object containing required data (except name and gname)
-         *@return Nothing
-         */
+     * @short  Initializes a StarObject to given data
+     *
+     * This is almost like the StarObject constructor itself, but it avoids
+     * setting up name, gname etc for unnamed stars. If called instead of the
+     * constructor, this method will be much faster for unnamed stars
+     *
+     * @param  stardata  Pointer to starData object containing required data (except name and gname)
+     * @return Nothing
+     */
     void init(const StarData *stardata);
 
     /**
-         *@short  Initializes a StarObject to given data
-         *
-         *@param  stardata  Pointer to deepStarData object containing the available data
-         *@return Nothing
-         */
+     * @short  Initializes a StarObject to given data
+     *
+     * @param  stardata  Pointer to deepStarData object containing the available data
+     * @return Nothing
+     */
     void init(const DeepStarData *stardata);
 
     /**
-         *@short  Sets the name, genetive name, and long name
-         *
-         *@param  name  Common name
-         *@param  name2 Genetive name
-         */
+     * @short  Sets the name, genetive name, and long name
+     *
+     * @param  name  Common name
+     * @param  name2 Genetive name
+     */
     void setNames(const QString &name, const QString &name2);
 
     /** @return true if the star has a name ("star" doesn't count) */
@@ -139,46 +143,52 @@ class StarObject : public SkyObject
     /** If star is unnamed return "star" otherwise return the longname */
     inline QString longname(void) const override { return hasLongName() ? LongName : starString; }
 
-    /** Returns entire spectral type string
-         * @return Spectral Type string
-         */
+    /**
+     * Returns entire spectral type string
+     * @return Spectral Type string
+     */
     QString sptype(void) const;
 
     /** Returns just the first character of the spectral type string. */
     char spchar() const;
 
-    /** Returns the genetive name of the star.
-         * @return genetive name of the star
-         */
+    /**
+     * Returns the genetive name of the star.
+     * @return genetive name of the star
+     */
     QString gname(bool useGreekChars = true) const;
 
-    /** Returns the greek letter portion of the star's genetive name.
-         * Returns empty string if star has no genetive name defined.
-         * @return greek letter portion of genetive name
-         */
+    /**
+     * Returns the greek letter portion of the star's genetive name.
+     * Returns empty string if star has no genetive name defined.
+     * @return greek letter portion of genetive name
+     */
     QString greekLetter(bool useGreekChars = true) const;
 
     /** @return the genitive form of the star's constellation. */
     QString constell(void) const;
 
-    /** Determine the current coordinates (RA, Dec) from the catalog
-         * coordinates (RA0, Dec0), accounting for both precession and nutation.
-         * @param num pointer to KSNumbers object containing current values of
-         * time-dependent variables.
-         * @param includePlanets does nothing in this implementation (see KSPlanetBase::updateCoords()).
-         * @param lat does nothing in this implementation (see KSPlanetBase::updateCoords()).
-         * @param LST does nothing in this implementation (see KSPlanetBase::updateCoords()).
-         */
+    /**
+     * Determine the current coordinates (RA, Dec) from the catalog
+     * coordinates (RA0, Dec0), accounting for both precession and nutation.
+     *
+     * @param num pointer to KSNumbers object containing current values of
+     * time-dependent variables.
+     * @param includePlanets does nothing in this implementation (see KSPlanetBase::updateCoords()).
+     * @param lat does nothing in this implementation (see KSPlanetBase::updateCoords()).
+     * @param LST does nothing in this implementation (see KSPlanetBase::updateCoords()).
+     */
     void updateCoords(const KSNumbers *num, bool includePlanets = true, const CachingDms *lat = nullptr,
                       const CachingDms *LST = nullptr, bool forceRecompute = false) override;
 
-    /** @short fills ra and dec with the coordinates of the star with the proper
-         * motion correction but without precesion and its friends.  It is used
-         * in StarComponent to re-index all the stars.
-         *
-         * @return true if we changed the coordinates, false otherwise
-         * NOTE: ra and dec both in degrees.
-         */
+    /**
+     * @short Fills ra and dec with the coordinates of the star with the proper
+     * motion correction but without precesion and its friends.  It is used
+     * in StarComponent to re-index all the stars.
+     *
+     * @return true if we changed the coordinates, false otherwise
+     * NOTE: ra and dec both in degrees.
+     */
     bool getIndexCoords(const KSNumbers *num, CachingDms &ra, CachingDms &dec);
     bool getIndexCoords(const KSNumbers *num, double *ra, double *dec);
 
@@ -193,20 +203,21 @@ class StarObject : public SkyObject
     }
 
     /**
-         *@short returns the square of the magnitude of the proper motion correction in (milliarcsec/year)^2
-         *@note This method is faster when the square root need not be taken
-         */
+     * @short returns the square of the magnitude of the proper motion correction in (milliarcsec/year)^2
+     * @note This method is faster when the square root need not be taken
+     */
     inline double pmMagnitudeSquared() const
     {
         double metric_weighted_pmRA = dec0().cos() * pmRA();
         return (metric_weighted_pmRA * metric_weighted_pmRA + pmDec() * pmDec());
     }
 
-    /** @short Set the Ra and Dec components of the star's proper motion, in milliarcsec/year.
-         * Note that the RA component is multiplied by cos(dec).
-         * @param pmra the new RA propoer motion
-         * @param pmdec the new Dec proper motion
-         */
+    /**
+     * @short Set the Ra and Dec components of the star's proper motion, in milliarcsec/year.
+     * Note that the RA component is multiplied by cos(dec).
+     * @param pmra the new RA propoer motion
+     * @param pmdec the new Dec proper motion
+     */
     inline void setProperMotion(double pmra, double pmdec)
     {
         PM_RA  = pmra;
@@ -228,8 +239,10 @@ class StarObject : public SkyObject
     /** @return the star's distance from the Sun in parsecs, as computed from the parallax. */
     inline double distance() const { return 1000. / parallax(); }
 
-    /** @short set the star's multiplicity flag (i.e., is it a binary or multiple star?)
-         * @param m true if binary/multiple star system */
+    /**
+     * @short set the star's multiplicity flag (i.e., is it a binary or multiple star?)
+     * @param m true if binary/multiple star system
+     */
     inline void setMultiple(bool m) { Multiplicity = m; }
 
     /** @return whether the star is a binary or multiple starobject */
@@ -238,47 +251,43 @@ class StarObject : public SkyObject
     /** @return the star's HD index */
     inline int getHDIndex() const { return HD; }
 
-    /** @short set the star's variability flag
-            *@param v true if star is variable
-            */
+    /**
+     * @short set the star's variability flag
+     *
+     * @param v true if star is variable
+     */
     inline void setVariable(bool v) { Variability = v; }
 
-    /** @return whether the star is a binary or multiple starobject
-            */
+    /** @return whether the star is a binary or multiple starobject */
     inline bool isVariable() const { return Variability; }
 
-    /** @short returns the name, the magnitude or both.
-         */
+    /** @short returns the name, the magnitude or both. */
     QString nameLabel(bool drawName, bool drawMag) const;
 
     QString labelString() const override;
 
     /**
-         *@return the pixel distance for offseting the star's name label
-         *This takes the zoom level and the star's brightness into account.
-         */
+     * @return the pixel distance for offseting the star's name label
+     * This takes the zoom level and the star's brightness into account.
+     */
     double labelOffset() const override;
 
-    /**
-         *@return the Visual magnitude of the star
-         */
+    /** @return the Visual magnitude of the star */
     inline float getVMag() const { return V; }
 
-    /**
-         *@return the blue magnitude of the star
-         */
+    /** @return the blue magnitude of the star */
     inline float getBMag() const { return B; }
 
     /**
-         *@return the B - V color index of the star, or a nonsense number
-         *larger than 30 if it's not well defined
-         */
+     * @return the B - V color index of the star, or a nonsense number
+     * larger than 30 if it's not well defined
+     */
     inline float getBVIndex() const { return ((B < 30.0 && V < 30.0) ? B - V : 99.9); }
 
     void initPopupMenu(KSPopupMenu *pmenu) override;
 
-    quint64 updateID;
-    quint64 updateNumID;
+    quint64 updateID { 0 };
+    quint64 updateNumID { 0 };
 
 #ifdef PROFILE_UPDATECOORDS
     static double updateCoordsCpuTime;
