@@ -87,10 +87,6 @@ WUTDialog::WUTDialog(QWidget *parent, bool _session, GeoLocation *_geo, KStarsDa
     QTimer::singleShot(0, this, SLOT(init()));
 }
 
-WUTDialog::~WUTDialog()
-{
-}
-
 void WUTDialog::makeConnections()
 {
     connect(WUT->DateButton, SIGNAL(clicked()), SLOT(slotChangeDate()));
@@ -289,9 +285,10 @@ void WUTDialog::slotLoadList(const QString &c)
             starObjects.append(data->skyComposite()->objectLists(SkyObject::STAR));
             starObjects.append(data->skyComposite()->objectLists(SkyObject::CATALOG_STAR));
 
-            for (QVector<QPair<QString, const SkyObject *>>::ConstIterator it = starObjects.cbegin();it != starObjects.cend(); ++it)
+            for (const auto &object : starObjects)
             {
-               const SkyObject *o =  (*it).second;
+               const SkyObject *o =  object.second;
+
                if (checkVisibility(o) && o->mag() <= m_Mag)
                {
                    visibleObjects(c).insert(o);
